@@ -20,7 +20,7 @@ multi_opt = partial(Option, multiple=True)
 tuple_opt = partial(Option, nargs=3)
 
 
-def mark_parametrize(argnames, *argvalues, **kwargs):
+def parametrize(argnames, *argvalues, **kwargs):
     return pytest.mark.parametrize(argnames, argvalues, **kwargs)
 
 
@@ -33,7 +33,7 @@ def make_fake_context(
     params: Iterable[str],
     command_cls=cloup.Command,
 ) -> Context:
-    """Creates an simple instance of Command with the specified parameters,
+    """Creates a simple instance of Command with the specified parameters,
     then create a fake context without actually invoking the command."""
     return Context(command_cls('fake', params=params, callback=noop))
 
